package problem.strips;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Set;

public class StripsProblem {
	
	private final ArrayList<String> facts;
	private final Set<Integer> init;
	private final Set<Integer> goal;
	private final List<StripsOperator> operators = new ArrayList<>();
	
	public StripsProblem(ArrayList<String> facts, Set<Integer> init, Set<Integer> goal, Collection<StripsOperator> operators) {
		super();
		this.facts = facts;
		this.init = init;
		this.goal = goal;
		this.operators.addAll(operators);
	}

	public List<String> getFacts() {
		return new ArrayList<>(facts);
	}
	
	public String getFactName(int fact) {
		return facts.get(fact);
	}

	public Set<Integer> getInit() {
		return init;
	}

	public Set<Integer> getGoal() {
		return goal;
	}

	public List<StripsOperator> getOperators() {
		return operators;
	}
	
	public String humanize(Set<Integer> factIDs) {
		String out = "{";
		for(int f : factIDs) {
			out += facts.get(f)+",";
		}
		out += "}";
		return out;
	}
	
	@Override
	public String toString() {
		String out = "StripsProblem:\nfacts:\n";
		for(String fact : facts) {
			out += " " + fact + "\n";
		}
		out += "init:\n"+humanize(init)+"\n";
		out += "goal:\n"+humanize(goal)+"\n";
		out += "operators:\n";
		for(StripsOperator op : operators){
			out += " "+op.getName()+"\n";
			out += "  pre:"+humanize(op.getPre())+"\n";
			out += "  add:"+humanize(op.getAdd())+"\n";
			out += "  del:"+humanize(op.getDel())+"\n";
			out += "  cost:"+op.getCost()+"\n";
		}
		
		return out;
	}

	

}
